@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2016 Olivier Girondel
+ *  Copyright 1994-2018 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -32,7 +32,7 @@ static char *source_names[2] = { NULL, NULL };
 
 
 static void
-jack_shutdown(__attribute__ ((unused)) void *arg)
+jack_shutdown(void *arg)
 {
   /* TODO: do not xerror */
   xerror("JACK shut down\n");
