@@ -38,7 +38,7 @@ create(Context_t *ctx)
     options |= BEQ_DISABLED;
   else {
     line = MAXY;
-    linebuf = xmalloc(WIDTH*sizeof(Pixel_t));
+    linebuf = xcalloc(WIDTH, sizeof(Pixel_t));
   }
 }
 
