@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2016 Olivier Girondel
+ *  Copyright 1994-2018 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -71,7 +71,7 @@ static float CUBE[8][3] =
 
 
 void
-create(__attribute__ ((unused)) Context_t *ctx)
+create(Context_t *ctx)
 {
   int e, v;
   const float ar = WIDTH / (float)HEIGHT;
@@ -87,7 +87,7 @@ create(__attribute__ ((unused)) Context_t *ctx)
 
 
 void
-destroy(__attribute__ ((unused)) Context_t *ctx)
+destroy(Context_t *ctx)
 {
 }
 
@@ -139,7 +139,7 @@ get_texture(Context_t *ctx, const u_char face, const u_char rgba)
 
 
 static void
-face(__attribute__ ((unused)) Context_t *ctx, const char f)
+face(Context_t *ctx, const char f)
 {
   switch (f) {
   case 0: // front face
