@@ -20,9 +20,9 @@
 #include "context.h"
 
 u_long id = 1089234657;
-u_long options = BEQ_UNIQUE;
+u_long options = BEQ_LAST;
 char dname[] = "Cross-recurrence plot";
-u_long mode = NORMAL;
+u_long mode = OVERLAY;
 char desc[] = "Cross-recurrence plot of the input";
 
 
@@ -58,7 +58,7 @@ get_color(const Input_t *input, const int i, const int j)
   float dy = input->data[A_LEFT][i+1]-input->data[A_RIGHT][j+1];
   float dz = input->data[A_LEFT][i+2]-input->data[A_RIGHT][j+2];
   float dt = input->data[A_LEFT][i+3]-input->data[A_RIGHT][j+3];
-  
+
   dx *= dx;
   dy *= dy;
   dz *= dz;
@@ -101,14 +101,14 @@ run(Context_t *ctx)
 		  * (float)(ctx->input->size-3.0));
     int last_i = -1;
     Pixel_t last_c = 0;
-		
+
     for (ii = 0; ii < MINSCREEN; ii++) {
       Pixel_t c = last_c;
       /* rescale toussa */
       int i = (int)((float)ii
 		    / (float)MINSCREEN
 		    * (float)(ctx->input->size-3.0));
-			
+
       /* oh oohh ooohhh */
       if (i != last_i) {
 	c = get_color(ctx->input, i, j);
