@@ -27,7 +27,6 @@ char desc[] = "Falling drops";
 
 
 #define FACTOR 0.0005     /* empirical value, as usual */
-#define NDROPS (u_long)((float)BUFFSIZE * FACTOR)
 
 #define MIN_X_SPEED -1
 #define MAX_X_SPEED 1
@@ -47,17 +46,22 @@ typedef struct Drop_s {
 static Drop_t *drops = NULL;
 static u_char drops_mode = 0;
 static u_long active_drops = 0;
+static u_long ndrops = 0;
 
 
 void
 create(Context_t *ctx)
 {
   u_long d;
-  assert(NDROPS > 0);
 
-  drops = xcalloc(NDROPS, sizeof(Drop_t));
-  
-  for (d = 0; d < NDROPS; d++)
+  ndrops = (u_long)((float)BUFFSIZE * FACTOR);
+  if (ndrops < 1) {
+    ndrops = 1;
+  }
+
+  drops = xcalloc(ndrops, sizeof(Drop_t));
+
+  for (d = 0; d < ndrops; d++)
     drops[d].active = 0;
 
   active_drops = 0;
@@ -67,7 +71,7 @@ create(Context_t *ctx)
 void
 destroy(Context_t *ctx)
 {
-  xfree(drops);  
+  xfree(drops);
 }
 
 
@@ -81,10 +85,10 @@ do_drops(Context_t *ctx)
 
   Buffer8_clear(dst);
 
-  for (d = 0; d < NDROPS; d++) {
+  for (d = 0; d < ndrops; d++) {
     if (!drops[d].active)
       continue;
-		
+
     for (m = 0; m < -drops[d].speed.y; m++) {
       u_char z;
       Point2d_t C;
@@ -95,22 +99,22 @@ do_drops(Context_t *ctx)
 	drops[d].pos.x = 0;
       else if (drops[d].pos.x > MAXX)
 	drops[d].pos.x = MAXX;
-			
+
       /* drops[d].pos = p2d_add (&drops[d].pos, &drops[d].speed); */
       drops[d].pos.y--;
-			
+
       if (!drops[d].pos.y)
 	continue;
-			
+
       z = drops[d].height;
-			
+
       /* now, move and set new height */
       /* go to center first */
       C.x = drops[d].pos.x;
       C.y = drops[d].pos.y - 1; /* is >= 0 */
-			
+
       Cz = get_pixel /*_nc*/ (src, C.x, C.y);
-			
+
       /* ceci est un commentaire ANSI C */
       if ((!drops_mode && (Cz < z)) || (drops_mode && (Cz > z))) {
 	drops[d].speed.y++;
@@ -121,29 +125,29 @@ do_drops(Context_t *ctx)
       } else {
 	Point2d_t L, R;
 	Pixel_t Lz, Rz;
-		
+
 	/* if (!drops[d].height++)
 	   drops[d].height = 255; */
-				
+
 	drops[d].height--;
-				
+
 	L.x = drops[d].pos.x-1;
 	if (L.x < 0)
 	  L.x = 0;
 	else if (L.x > MAXX)
 	  L.x = MAXX;
 	L.y = C.y;
-				
+
 	R.x = drops[d].pos.x+1;
 	if (R.x < 0)
 	  R.x = 0;
 	else if (R.x > MAXX)
 	  R.x = MAXX;
 	R.y = C.y;
-				
+
 	Lz = get_pixel/*_nc*/(src, L.x, L.y);
 	Rz = get_pixel/*_nc*/(src, R.x, R.y);
-				
+
 	/* choose either LCR or RCL */
 	if (b_rand_boolean()) {
 	  /* LCR */
@@ -165,23 +169,23 @@ do_drops(Context_t *ctx)
 	  }
 	}
       }
-			
+
       /* if (drops[d].height)
 	 drops[d].height--; */
-			
+
       /* clamp speed */
       if (drops[d].speed.x < MIN_X_SPEED)
 	drops[d].speed.x = MIN_X_SPEED;
       else if (drops[d].speed.x > MAX_X_SPEED)
 	drops[d].speed.x = MAX_X_SPEED;
-			
+
       /* ok this one is tricky, i admit ;) */
       if (drops[d].speed.y > -MIN_Y_SPEED)
 	drops[d].speed.y = -MIN_Y_SPEED;
       else if (drops[d].speed.y < -MAX_Y_SPEED)
 	drops[d].speed.y = -MAX_Y_SPEED;
     }
-		
+
     if (drops[d].pos.y)
       set_pixel/*_nc*/(dst, drops[d].pos.x, drops[d].pos.y, drops[d].height);
   }
@@ -192,7 +196,7 @@ static void
 decay_drops()
 {
   u_long d;
-  for (d = 0; d < NDROPS; d++)
+  for (d = 0; d < ndrops; d++)
     if (drops[d].active)
       if ((drops[d].pos.y <= 0) || !drops[d].height) {
 	drops[d].active = 0;
@@ -213,8 +217,8 @@ run(Context_t *ctx)
   pthread_mutex_lock(&ctx->input->mutex);
 
   for (nd = 0, idx = 0;
-       (nd < ctx->input->size) && (idx < NDROPS)
-	 && (active_drops < NDROPS);
+       (nd < ctx->input->size) && (idx < ndrops)
+	 && (active_drops < ndrops);
        idx++) {
     if (drops[idx].active)
       continue;
@@ -228,7 +232,7 @@ run(Context_t *ctx)
     drops[idx].height = 255; /* Input_random_u_float () * 128 + 127; */
     active_drops++;
     nd++;
-    assert(active_drops <= NDROPS);
+    assert(active_drops <= ndrops);
   }
 
   pthread_mutex_unlock(&ctx->input->mutex);
