@@ -29,13 +29,13 @@ void
 run(Context_t *ctx)
 {
   const Buffer8_t *src = active_buffer(ctx);
-  Buffer8_t *dst = passive_buffer (ctx);
+  Buffer8_t *dst = passive_buffer(ctx);
   
   const Pixel_t* nw = src->buffer;
   const Pixel_t* se = src->buffer + 2 * WIDTH + 2;
   
   Pixel_t *d;
   
-  for (d = dst->buffer + WIDTH + 1; d < dst->buffer + (BUFFSIZE - WIDTH); )
+  for (d = dst->buffer + WIDTH + 1; d < dst->buffer + (BUFFSIZE - WIDTH - 1); )
     *d++ = ((*nw++ - *se++) / 2) + 128;
 }
