@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2016 Olivier Girondel
+ *  Copyright 1994-2018 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -44,7 +44,7 @@ randomize(Buffer8_t *buff)
 
 
 void
-create(__attribute__ ((unused)) Context_t *ctx)
+create(Context_t *ctx)
 {
   game = Buffer8_new();
   game2 = Buffer8_new();
@@ -53,7 +53,7 @@ create(__attribute__ ((unused)) Context_t *ctx)
 
 
 void
-destroy(__attribute__ ((unused)) Context_t *ctx)
+destroy(Context_t *ctx)
 {
   Buffer8_delete(game);
   Buffer8_delete(game2);
@@ -61,7 +61,7 @@ destroy(__attribute__ ((unused)) Context_t *ctx)
 
 
 void
-on_switch_on(__attribute__ ((unused)) Context_t *ctx)
+on_switch_on(Context_t *ctx)
 {
   randomize(game);
   Buffer8_average(game, active_buffer(ctx));
