@@ -21,7 +21,7 @@
 
 
 u_long id = 1077223395;
-u_long options = BE_GFX|BEQ_FLUSH|BEQ_NORANDOM;
+u_long options = BE_GFX|BEQ_UNIQUE|BEQ_NORANDOM;
 char desc[] = "Cellular automaton";
 
 
