@@ -85,77 +85,24 @@ typedef struct {
 static swarmstruct swarm;
 
 
-static void
-free_segs(swarmstruct *sp)
-{
-  free(sp->segs);
-  sp->segs = (Line_t *) NULL;
-}
-
-
-static void
-free_bees(swarmstruct *sp)
-{
-  free_segs(sp); 
-  free(sp->x);
-  sp->x = (float *) NULL;
-  free(sp->y);
-  sp->y = (float *) NULL;
-  free(sp->xv);
-  sp->xv = (float *) NULL;
-  free(sp->yv);
-  sp->yv = (float *) NULL;
-}
-
-
-static void
-free_swarm()
-{
-  free_bees(&swarm);
-}
-
-
 void
 create(Context_t *ctx)
 {
   int b, t;
 
   swarm.beecount = 100;
-  if (swarm.beecount < -MINBEES) {
-    swarm.beecount = NRAND(-swarm.beecount - MINBEES + 1) + MINBEES;
-    /* if swarm.beecount is random ... the size can change */
-    free_bees(&swarm);
-  } else if (swarm.beecount < MINBEES)
-    swarm.beecount = MINBEES;
-  swarm.taillen = 100 ;
-  if (swarm.taillen < -MINTRAIL) {
-    /* Change by sqr so its seems more variable */
-    swarm.taillen = NRAND((int) sqrt((double) (-swarm.taillen - MINTRAIL + 1)));
-    swarm.taillen = swarm.taillen * swarm.taillen + MINTRAIL;
-    /* free_segs(swarm); */
-  } else if (swarm.taillen < MINTRAIL)
-    swarm.taillen = MINTRAIL;
-
+  swarm.taillen = 100;
   swarm.border = 50;
   swarm.tick = 0;
   swarm.rolloverflag = 0;
 
   /* Allocate memory. */
-  if (swarm.segs == NULL) {
-    if (((swarm.segs = malloc(sizeof(Line_t) *
-					 swarm.beecount)) == NULL) ||
-	((swarm.x = malloc(sizeof(float) * swarm.beecount *
-				     swarm.taillen)) == NULL) ||
-	((swarm.y = malloc(sizeof(float) * swarm.beecount *
-				     swarm.taillen)) == NULL) ||
-	((swarm.xv = malloc(sizeof(float) *
-				      swarm.beecount)) == NULL) ||
-	((swarm.yv = malloc(sizeof(float) *
-				      swarm.beecount)) == NULL)) {
-      free_swarm();
-      return;
-    }
-  }
+  swarm.segs = xmalloc(sizeof(Line_t) * swarm.beecount);
+  swarm.x = xmalloc(sizeof(float) * swarm.beecount * swarm.taillen);
+  swarm.y = xmalloc(sizeof(float) * swarm.beecount * swarm.taillen);
+  swarm.xv = xmalloc(sizeof(float) * swarm.beecount);
+  swarm.yv = xmalloc(sizeof(float) * swarm.beecount);
+
   /* Initialize point positions, velocities, etc. */
   /* wasp */
   swarm.wx[0] = swarm.border + NRAND(WIDTH - 2 * swarm.border);
@@ -182,9 +129,9 @@ create(Context_t *ctx)
 void
 run(Context_t *ctx)
 {
-  int         b, newlimit;
-  short       prev;
-  float       speed;
+  int       b, newlimit;
+  short     prev;
+  float     speed;
   Buffer8_t *dst = passive_buffer(ctx);
 
   Buffer8_clear(dst);
@@ -228,12 +175,12 @@ run(Context_t *ctx)
   /* <=- Bees -=> */
   swarm.tick = (swarm.tick+1) % (swarm.taillen);
   prev = (swarm.tick) ? swarm.tick - 1 : swarm.taillen - 1; 
-	
+
   if (swarm.tick == swarm.taillen - 1)
     swarm.rolloverflag = 1;
   for (b = 0; b < swarm.beecount; b++) {
     int distance, dx, dy;
-		
+
     /* Accelerate */
     dx = (int) (swarm.wx[1] - X(prev, b));
     dy = (int) (swarm.wy[1] - Y(prev, b));
@@ -250,10 +197,11 @@ run(Context_t *ctx)
       swarm.xv[b] *= newlimit;
       swarm.yv[b] *= newlimit;
     }
+
     /* Move */
     X(swarm.tick, b) = X(prev, b) + swarm.xv[b];
     Y(swarm.tick, b) = Y(prev, b) + swarm.yv[b];
- 
+
     /* Fill the segment lists. */
     swarm.segs[b].x1 = (short) X(swarm.tick, b);
     swarm.segs[b].y1 = (short) Y(swarm.tick, b);
@@ -270,5 +218,9 @@ run(Context_t *ctx)
 void
 destroy(Context_t *ctx)
 {
-  free_swarm();
+  xfree(swarm.segs);
+  xfree(swarm.x);
+  xfree(swarm.y);
+  xfree(swarm.xv);
+  xfree(swarm.yv);
 }
