@@ -30,7 +30,7 @@ static u_char size;
 
 static Shuffler_t *shf = NULL;
 
-#define MIN_SIZE 40
+#define MIN_SIZE 20
 #define MAX_SIZE 200
 
 #define TAQUIN_MIN -10;
@@ -42,7 +42,10 @@ enum Dirs { SLIDE_RL, SLIDE_DT, SLIDE_LR, SLIDE_TD };
 static u_short hole_x, hole_y, new_hole_x=0, new_hole_y=0;
 static short   step;
 static enum Dirs    dir;
-static u_long  *map;
+static u_long  *map = NULL;
+
+// #define TAQUIN_ORIGINAL // Define to get invalid writes
+// #define TAQUIN_ASSERT   // Define to crash with assertions
 
 
 static inline void
@@ -68,10 +71,10 @@ is_ok(const u_short size)
 }
 
 
-static inline u_char
+static inline u_short
 get_size()
 {
-  return (u_char)Shuffler_get(shf);
+  return Shuffler_get(shf);
 }
 
 
@@ -154,7 +157,7 @@ prepare(Shuffler_t *shf)
 {
   int i;
 
-  /* disable too little sizes */
+  /* disable too small sizes */
   for (i = 0; i < MIN_SIZE; i++)
     Shuffler_disable(shf, i);
 }
@@ -180,8 +183,7 @@ create(Context_t *ctx)
 void
 destroy(Context_t *ctx)
 {
-  if (NULL != map)
-    xfree(map);
+  xfree(map);
 
   if (NULL != shf)
     Shuffler_delete(shf);
@@ -215,9 +217,32 @@ slide_lr_1(u_short from, u_short to, u_short y)
 {
   u_short x;
 
+  // XXX FIXME Code below does invalid writes
+#ifdef TAQUIN_ORIGINAL
   for (x = to; x > from; --x)
     map[(y * WIDTH) + x] = map[(y * WIDTH) + x - 1];
   map[(y * WIDTH) + from] = 0;
+#else
+  // XXX FIXME Temporary workaround
+  for (x = to; x > from; --x) {
+    long dst = (y * WIDTH) + x;
+    long src = (y * WIDTH) + x - 1;
+#ifdef TAQUIN_ASSERT
+    printf("size: %d, BUFFSIZE: %ld, dst: %ld, src: %ld\n", size, BUFFSIZE, dst, src);
+    assert(dst >= 0);
+    assert(dst < (long)BUFFSIZE);
+#else
+    if ((dst >= 0) && (dst < (long)BUFFSIZE))
+#endif
+      map[dst] = map[src];
+  }
+  long null = (y * WIDTH) + from;
+#ifdef TAQUIN_ASSERT
+  assert(null >= 0);
+  assert(null < (long)BUFFSIZE);
+#endif
+  map[null] = 0;
+#endif
 }
 
 
@@ -226,9 +251,32 @@ slide_td_1(u_short from, u_short to, u_short x)
 {
   u_short y;
 
+  // XXX FIXME Code below does invalid writes
+#ifdef TAQUIN_ORIGINAL
   for (y = to; y > from; --y)
     map[(y * WIDTH) + x] = map[((y - 1) * WIDTH) + x];
   map[(from * WIDTH) + x] = 0;
+#else
+  // XXX FIXME Temporary workaround
+  for (y = to; y > from; --y) {
+    long dst = (y * WIDTH) + x;
+    long src = ((y - 1) * WIDTH) + x;
+#ifdef TAQUIN_ASSERT
+    printf("size: %d, BUFFSIZE: %ld, dst: %ld, src: %ld\n", size, BUFFSIZE, dst, src);
+    assert(dst >= 0);
+    assert(dst < (long)BUFFSIZE);
+#else
+    if ((dst >= 0) && (dst < (long)BUFFSIZE))
+#endif
+      map[dst] = map[src];
+  }
+  long null = (from * WIDTH) + x;
+#ifdef TAQUIN_ASSERT
+  assert(null >= 0);
+  assert(null < (long)BUFFSIZE);
+#endif
+  map[null] = 0;
+#endif
 }
 
 
@@ -293,7 +341,7 @@ run(Context_t *ctx)
   const Buffer8_t *src = active_buffer(ctx);
   Buffer8_t *dst = passive_buffer(ctx);
 	
-  if (step <0) 
+  if (step < 0)
     ++step;
   else { 
     if (++step == (size + 1)) {
