@@ -33,8 +33,8 @@ run(Context_t *ctx)
   Buffer8_t *wrk = active_buffer(ctx);  
 
   for (j = 0; j <= HHEIGHT; j++)
-    memcpy((void *)(&wrk->buffer[j * WIDTH]),
-	   (const void *)(&wrk->buffer[(MAXY - j) * WIDTH]),
+    memcpy((void *)(&wrk->buffer[(MAXY - j) * WIDTH]),
+	   (const void *)(&wrk->buffer[j * WIDTH]),
 	   WIDTH * sizeof(Pixel_t));
   Buffer8_copy(active_buffer(ctx), passive_buffer(ctx));
 }
