@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2016 Olivier Girondel
+ *  Copyright 1994-2018 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -329,7 +329,7 @@ print(float x, float y, const char *text, float *len)
 u_short
 osd_print(const u_short x, u_short y,
 	  const u_char rev_x, const u_char rev_y,
-	  __attribute__ ((unused)) const u_char mode, const int disabled, const char *fmt, ...)
+	  const u_char mode, const int disabled, const char *fmt, ...)
 {
   char str[OSD_BUFFLEN+1];
   va_list ap;
