@@ -50,9 +50,6 @@ biniou_sdl_set_videomode(const u_short width, const u_short height, const Uint32
 	   width, height, drv.sc->format->BitsPerPixel);
 #endif
   drv.must_lock_screen = SDL_MUSTLOCK(drv.sc);
-#ifdef XDEBUG
-  printf("[+] Do we have to lock the screen ? %s\n", drv.must_lock_screen ? "yes" : "no");
-#endif
 }
 
 
@@ -102,6 +99,7 @@ SDL_get_event(Context_t *ctx)
   // TODO middle = change color, right = erase (3x3)
 
   SDL_Event evt;
+  memset(&evt, 0, sizeof(SDL_Event));
 
   while (SDL_PollEvent(&evt) != 0) {
     BKey_t key;
