@@ -128,8 +128,13 @@ osd_info(const Context_t *ctx) {
 		      ((ctx->sm->cur->auto_colormaps) ? "On" : "Off"));
   
   if ((pictures != NULL) && (pictures->size > 1))
-    (void)osd_print(BORDER, dst_y, 0, 0, ctx->osd_mode, 0, "Random picture: %s",   
-		    (ctx->sm->cur->auto_pictures ? "On" : "Off"));
+    dst_y = osd_print(BORDER, dst_y, 0, 0, ctx->osd_mode, 0, "Random picture: %s",
+		      (ctx->sm->cur->auto_pictures ? "On" : "Off"));
+
+  /* Display locked plugin, if any */
+  if (ctx->locked != NULL)
+    dst_y = osd_print(BORDER, dst_y, 0, 0, ctx->osd_mode, 0, "Locked: %s",
+		      ctx->locked->dname);
 }
 
 
