@@ -26,19 +26,6 @@
 #include "pnglite.h"
 
 
-static void
-exit_if_r00t()
-{
-  uid_t uid = getuid();
-
-  if (0 == uid) {
-    fprintf(stderr, "You do not run programs linked against the biniou library\n"
-	    "with root privileges, do you ?\n");
-    exit(1);
-  }
-}
-
-
 void
 biniou_new(const char *datadir, const char *pluginsdir,
 	   const char *schemes, const char *themes,
@@ -49,8 +36,6 @@ biniou_new(const char *datadir, const char *pluginsdir,
 {
   char *buf;
 
-  exit_if_r00t();
-
   if (options & B_INIT_VERBOSE)
     libbiniou_verbose = 1;
 
@@ -68,25 +53,13 @@ biniou_new(const char *datadir, const char *pluginsdir,
   if (datadir != NULL) {
     /* Pictures */
     buf = g_strdup_printf("%s/images/", datadir);
-    VERBOSE(
-#ifdef XDEBUG
-      printf("[+] Loading pictures from %s\n", buf)
-#else
-      printf("[+] Loading pictures\n")
-#endif
-      );
+    VERBOSE(printf("[+] Loading pictures\n"));
     Pictures_new(buf, themes);
     g_free(buf);
 	  
     /* Colormaps */
     buf = g_strdup_printf("%s/colormaps/", datadir);
-    VERBOSE (
-#ifdef XDEBUG
-      printf("[+] Loading colormaps from %s: ", buf)
-#else
-      printf("[+] Loading colormaps: ")
-#endif
-      );
+    VERBOSE(printf("[+] Loading colormaps\n"));
     Colormaps_new(buf);
     g_free(buf);
   } else {
