@@ -27,9 +27,9 @@
 Buffer8_t *
 Buffer8_new()
 {
-  Buffer8_t *buff = av_malloc(sizeof(Buffer8_t));
+  Buffer8_t *buff = xcalloc(1, sizeof(Buffer8_t));
 
-  buff->buffer = av_malloc(BUFFSIZE*sizeof(Pixel_t));
+  buff->buffer = xcalloc(BUFFSIZE, sizeof(Pixel_t));
 
   return buff;
 }
@@ -38,9 +38,9 @@ Buffer8_new()
 Buffer8_t *
 Buffer8_clone(const Buffer8_t *src)
 {
-  Buffer8_t *buff = av_malloc(sizeof(Buffer8_t));
+  Buffer8_t *buff = xmalloc(sizeof(Buffer8_t));
 
-  buff->buffer = av_malloc(BUFFSIZE*sizeof(Pixel_t));
+  buff->buffer = xcalloc(BUFFSIZE, sizeof(Pixel_t));
   Buffer8_copy(src, buff);
 
   return buff;
@@ -50,8 +50,9 @@ Buffer8_clone(const Buffer8_t *src)
 void
 Buffer8_delete(Buffer8_t *buff)
 {
-  av_free(buff->buffer);
-  av_free(buff);
+  if (buff != NULL)
+    xfree(buff->buffer);
+  xfree(buff);
 }
 
 
@@ -138,12 +139,6 @@ draw_line(Buffer8_t *buff, short x1, short y1, short x2, short y2, const Pixel_t
     return;
   }
 	
-#ifdef XDEBUG
-  if ((x1 < MINX) || (x1 > MAXX) || (y1 < MINY) || (y1 > MAXY)
-      || (x2 < MINX) || (x2 > MAXX) || (y2 < MINY) || (y2 > MAXY))
-    assert(0); /* xerror("draw_line\n"); */
-#endif
-      
   /* Bresenham Algorithm */
   if (x1 > x2) {
     swap(&x1, &x2);
@@ -243,7 +238,7 @@ Buffer8_overlay(Buffer8_t *s1, const Buffer8_t *s2)
 {
   /* Take pixels from s2 if they are != 0 */
   Pixel_t *d = s1->buffer;
-  Pixel_t *s = (Pixel_t *)s2->buffer;
+  const Pixel_t *s = s2->buffer;
 
   for ( ; d < s1->buffer + BUFFSIZE*sizeof(Pixel_t); d++, s++)
     *d = (Pixel_t)((*s) ? *s : *d);
@@ -295,7 +290,13 @@ gray_scale(Pixel_t *grey_to, const uint16_t width, const uint16_t height, const
   srcSlice[0] = (const uint8_t *)grey_data;
   dst[0] = (uint8_t *)grey_to;
 
-  ret = sws_scale(sws_context, srcSlice, srcStride, 0, height, dst, dstStride);
+  ret = sws_scale(sws_context,
+		  srcSlice,
+		  srcStride,
+		  0,
+		  height,
+		  dst,
+		  dstStride);
   if (ret < 0)
     xerror("sws_scale\n");
 
